# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: entdb.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0b\x65ntdb.proto\x12\x08\x65ntdb.v1\"D\n\x0eRequestContext\x12\x11\n\ttenant_id\x18\x01 \x01(\t\x12\r\n\x05\x61\x63tor\x18\x02 \x01(\t\x12\x10\n\x08trace_id\x18\x03 \x01(\t\"N\n\x07Receipt\x12\x11\n\ttenant_id\x18\x01 \x01(\t\x12\x17\n\x0fidempotency_key\x18\x02 \x01(\t\x12\x17\n\x0fstream_position\x18\x03 \x01(\t\"\xce\x01\n\x14\x45xecuteAtomicRequest\x12)\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x18.entdb.v1.RequestContext\x12\x17\n\x0fidempotency_key\x18\x02 \x01(\t\x12\x1a\n\x12schema_fingerprint\x18\x03 \x01(\t\x12\'\n\noperations\x18\x04 \x03(\x0b\x32\x13.entdb.v1.Operation\x12\x14\n\x0cwait_applied\x18\x05 \x01(\x08\x12\x17\n\x0fwait_timeout_ms\x18\x06 \x01(\x05\"\xfc\x01\n\tOperation\x12-\n\x0b\x63reate_node\x18\x01 \x01(\x0b\x32\x16.entdb.v1.CreateNodeOpH\x00\x12-\n\x0bupdate_node\x18\x02 \x01(\x0b\x32\x16.entdb.v1.UpdateNodeOpH\x00\x12-\n\x0b\x64\x65lete_node\x18\x03 \x01(\x0b\x32\x16.entdb.v1.DeleteNodeOpH\x00\x12-\n\x0b\x63reate_edge\x18\x04 \x01(\x0b\x32\x16.entdb.v1.CreateEdgeOpH\x00\x12-\n\x0b\x64\x65lete_edge\x18\x05 \x01(\x0b\x32\x16.entdb.v1.DeleteEdgeOpH\x00\x42\x04\n\x02op\"o\n\x0c\x43reateNodeOp\x12\x0f\n\x07type_id\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\t\x12\x11\n\tdata_json\x18\x03 \x01(\t\x12\x10\n\x08\x61\x63l_json\x18\x04 \x01(\t\x12\n\n\x02\x61s\x18\x05 \x01(\t\x12\x11\n\tfanout_to\x18\x06 \x03(\t\"S\n\x0cUpdateNodeOp\x12\x0f\n\x07type_id\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\t\x12\x12\n\npatch_json\x18\x03 \x01(\t\x12\x12\n\nfield_mask\x18\x04 \x03(\t\"+\n\x0c\x44\x65leteNodeOp\x12\x0f\n\x07type_id\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\t\"s\n\x0c\x43reateEdgeOp\x12\x0f\n\x07\x65\x64ge_id\x18\x01 \x01(\x05\x12\x1f\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x11.entdb.v1.NodeRef\x12\x1d\n\x02to\x18\x03 \x01(\x0b\x32\x11.entdb.v1.NodeRef\x12\x12\n\nprops_json\x18\x04 \x01(\t\"_\n\x0c\x44\x65leteEdgeOp\x12\x0f\n\x07\x65\x64ge_id\x18\x01 \x01(\x05\x12\x1f\n\x04\x66rom\x18\x02 \x01(\x0b\x32\x11.entdb.v1.NodeRef\x12\x1d\n\x02to\x18\x03 \x01(\x0b\x32\x11.entdb.v1.NodeRef\"\\\n\x07NodeRef\x12\x0c\n\x02id\x18\x01 \x01(\tH\x00\x12\x13\n\talias_ref\x18\x02 \x01(\tH\x00\x12\'\n\x05typed\x18\x03 \x01(\x0b\x32\x16.entdb.v1.TypedNodeRefH\x00\x42\x05\n\x03ref\"+\n\x0cTypedNodeRef\x12\x0f\n\x07type_id\x18\x01 \x01(\x05\x12\n\n\x02id\x18\x02 \x01(\t\"\xba\x01\n\x15\x45xecuteAtomicResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\"\n\x07receipt\x18\x02 \x01(\x0b\x32\x11.entdb.v1.Receipt\x12\r\n\x05\x65rror\x18\x03 \x01(\t\x12\x12\n\nerror_code\x18\x04 \x01(\t\x12\x18\n\x10\x63reated_node_ids\x18\x05 \x03(\t\x12/\n\x0e\x61pplied_status\x18\x06 \x01(\x0e\x32\x17.entdb.v1.ReceiptStatus\"]\n\x17GetReceiptStatusRequest\x12)\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x18.entdb.v1.RequestContext\x12\x17\n\x0fidempotency_key\x18\x02 \x01(\t\"R\n\x18GetReceiptStatusResponse\x12\'\n\x06status\x18\x01 \x01(\x0e\x32\x17.entdb.v1.ReceiptStatus\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"]\n\x0eGetNodeRequest\x12)\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x18.entdb.v1.RequestContext\x12\x0f\n\x07type_id\x18\x02 \x01(\x05\x12\x0f\n\x07node_id\x18\x03 \x01(\t\">\n\x0fGetNodeResponse\x12\x1c\n\x04node\x18\x01 \x01(\x0b\x32\x0e.entdb.v1.Node\x12\r\n\x05\x66ound\x18\x02 \x01(\x08\"_\n\x0fGetNodesRequest\x12)\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x18.entdb.v1.RequestContext\x12\x0f\n\x07type_id\x18\x02 \x01(\x05\x12\x10\n\x08node_ids\x18\x03 \x03(\t\"F\n\x10GetNodesResponse\x12\x1d\n\x05nodes\x18\x01 \x03(\x0b\x32\x0e.entdb.v1.Node\x12\x13\n\x0bmissing_ids\x18\x02 \x03(\t\"\xa9\x01\n\x11QueryNodesRequest\x12)\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x18.entdb.v1.RequestContext\x12\x0f\n\x07type_id\x18\x02 \x01(\x05\x12\x13\n\x0b\x66ilter_json\x18\x03 \x01(\t\x12\r\n\x05limit\x18\x04 \x01(\x05\x12\x0e\n\x06offset\x18\x05 \x01(\x05\x12\x10\n\x08order_by\x18\x06 \x01(\t\x12\x12\n\ndescending\x18\x07 \x01(\x08\"Z\n\x12QueryNodesResponse\x12\x1d\n\x05nodes\x18\x01 \x03(\x0b\x32\x0e.entdb.v1.Node\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x12\x10\n\x08has_more\x18\x03 \x01(\x08\"\xa0\x01\n\x04Node\x12\x11\n\ttenant_id\x18\x01 \x01(\t\x12\x0f\n\x07node_id\x18\x02 \x01(\t\x12\x0f\n\x07type_id\x18\x03 \x01(\x05\x12\x14\n\x0cpayload_json\x18\x04 \x01(\t\x12\x12\n\ncreated_at\x18\x05 \x01(\x03\x12\x12\n\nupdated_at\x18\x06 \x01(\x03\x12\x13\n\x0bowner_actor\x18\x07 \x01(\t\x12\x10\n\x08\x61\x63l_json\x18\x08 \x01(\t\"\x82\x01\n\x0fGetEdgesRequest\x12)\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x18.entdb.v1.RequestContext\x12\x0f\n\x07node_id\x18\x02 \x01(\t\x12\x14\n\x0c\x65\x64ge_type_id\x18\x03 \x01(\x05\x12\r\n\x05limit\x18\x04 \x01(\x05\x12\x0e\n\x06offset\x18\x05 \x01(\x05\"C\n\x10GetEdgesResponse\x12\x1d\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x0e.entdb.v1.Edge\x12\x10\n\x08has_more\x18\x02 \x01(\x08\"\x81\x01\n\x04\x45\x64ge\x12\x11\n\ttenant_id\x18\x01 \x01(\t\x12\x14\n\x0c\x65\x64ge_type_id\x18\x02 \x01(\x05\x12\x14\n\x0c\x66rom_node_id\x18\x03 \x01(\t\x12\x12\n\nto_node_id\x18\x04 \x01(\t\x12\x12\n\nprops_json\x18\x05 \x01(\t\x12\x12\n\ncreated_at\x18\x06 \x01(\x03\"\x99\x01\n\x14SearchMailboxRequest\x12)\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x18.entdb.v1.RequestContext\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\r\n\x05query\x18\x03 \x01(\t\x12\x17\n\x0fsource_type_ids\x18\x04 \x03(\x05\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\x0e\n\x06offset\x18\x06 \x01(\x05\"Y\n\x15SearchMailboxResponse\x12.\n\x07results\x18\x01 \x03(\x0b\x32\x1d.entdb.v1.MailboxSearchResult\x12\x10\n\x08has_more\x18\x02 \x01(\x08\"\\\n\x13MailboxSearchResult\x12#\n\x04item\x18\x01 \x01(\x0b\x32\x15.entdb.v1.MailboxItem\x12\x0c\n\x04rank\x18\x02 \x01(\x02\x12\x12\n\nhighlights\x18\x03 \x01(\t\"\xae\x01\n\x11GetMailboxRequest\x12)\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x18.entdb.v1.RequestContext\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x16\n\x0esource_type_id\x18\x03 \x01(\x05\x12\x11\n\tthread_id\x18\x04 \x01(\t\x12\x13\n\x0bunread_only\x18\x05 \x01(\x08\x12\r\n\x05limit\x18\x06 \x01(\x05\x12\x0e\n\x06offset\x18\x07 \x01(\x05\"b\n\x12GetMailboxResponse\x12$\n\x05items\x18\x01 \x03(\x0b\x32\x15.entdb.v1.MailboxItem\x12\x14\n\x0cunread_count\x18\x02 \x01(\x05\x12\x10\n\x08has_more\x18\x03 \x01(\x08\"\xb9\x01\n\x0bMailboxItem\x12\x0f\n\x07item_id\x18\x01 \x01(\t\x12\x0e\n\x06ref_id\x18\x02 \x01(\t\x12\x16\n\x0esource_type_id\x18\x03 \x01(\x05\x12\x16\n\x0esource_node_id\x18\x04 \x01(\t\x12\x11\n\tthread_id\x18\x05 \x01(\t\x12\n\n\x02ts\x18\x06 \x01(\x03\x12\x12\n\nstate_json\x18\x07 \x01(\t\x12\x0f\n\x07snippet\x18\x08 \x01(\t\x12\x15\n\rmetadata_json\x18\t \x01(\t\"\x0f\n\rHealthRequest\"\xa3\x01\n\x0eHealthResponse\x12\x0f\n\x07healthy\x18\x01 \x01(\x08\x12\x0f\n\x07version\x18\x02 \x01(\t\x12<\n\ncomponents\x18\x03 \x03(\x0b\x32(.entdb.v1.HealthResponse.ComponentsEntry\x1a\x31\n\x0f\x43omponentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"6\n\x10GetSchemaRequest\x12\x0f\n\x07type_id\x18\x01 \x01(\x05\x12\x11\n\ttenant_id\x18\x02 \x01(\t\"=\n\x11GetSchemaResponse\x12\x13\n\x0bschema_json\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\"\x14\n\x12ListTenantsRequest\"<\n\x13ListTenantsResponse\x12%\n\x07tenants\x18\x01 \x03(\x0b\x32\x14.entdb.v1.TenantInfo\"\x1f\n\nTenantInfo\x12\x11\n\ttenant_id\x18\x01 \x01(\t\",\n\x17ListMailboxUsersRequest\x12\x11\n\ttenant_id\x18\x01 \x01(\t\",\n\x18ListMailboxUsersResponse\x12\x10\n\x08user_ids\x18\x01 \x03(\t*~\n\rReceiptStatus\x12\x1a\n\x16RECEIPT_STATUS_UNKNOWN\x10\x00\x12\x1a\n\x16RECEIPT_STATUS_PENDING\x10\x01\x12\x1a\n\x16RECEIPT_STATUS_APPLIED\x10\x02\x12\x19\n\x15RECEIPT_STATUS_FAILED\x10\x03\x32\xd8\x07\n\x0c\x45ntDBService\x12P\n\rExecuteAtomic\x12\x1e.entdb.v1.ExecuteAtomicRequest\x1a\x1f.entdb.v1.ExecuteAtomicResponse\x12Y\n\x10GetReceiptStatus\x12!.entdb.v1.GetReceiptStatusRequest\x1a\".entdb.v1.GetReceiptStatusResponse\x12>\n\x07GetNode\x12\x18.entdb.v1.GetNodeRequest\x1a\x19.entdb.v1.GetNodeResponse\x12\x41\n\x08GetNodes\x12\x19.entdb.v1.GetNodesRequest\x1a\x1a.entdb.v1.GetNodesResponse\x12G\n\nQueryNodes\x12\x1b.entdb.v1.QueryNodesRequest\x1a\x1c.entdb.v1.QueryNodesResponse\x12\x45\n\x0cGetEdgesFrom\x12\x19.entdb.v1.GetEdgesRequest\x1a\x1a.entdb.v1.GetEdgesResponse\x12\x43\n\nGetEdgesTo\x12\x19.entdb.v1.GetEdgesRequest\x1a\x1a.entdb.v1.GetEdgesResponse\x12P\n\rSearchMailbox\x12\x1e.entdb.v1.SearchMailboxRequest\x1a\x1f.entdb.v1.SearchMailboxResponse\x12G\n\nGetMailbox\x12\x1b.entdb.v1.GetMailboxRequest\x1a\x1c.entdb.v1.GetMailboxResponse\x12;\n\x06Health\x12\x17.entdb.v1.HealthRequest\x1a\x18.entdb.v1.HealthResponse\x12\x44\n\tGetSchema\x12\x1a.entdb.v1.GetSchemaRequest\x1a\x1b.entdb.v1.GetSchemaResponse\x12J\n\x0bListTenants\x12\x1c.entdb.v1.ListTenantsRequest\x1a\x1d.entdb.v1.ListTenantsResponse\x12Y\n\x10ListMailboxUsers\x12!.entdb.v1.ListMailboxUsersRequest\x1a\".entdb.v1.ListMailboxUsersResponseB#Z!github.com/example/entdb/proto/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'entdb_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z!github.com/example/entdb/proto/v1'
  _HEALTHRESPONSE_COMPONENTSENTRY._options = None
  _HEALTHRESPONSE_COMPONENTSENTRY._serialized_options = b'8\001'
  _globals['_RECEIPTSTATUS']._serialized_start=4009
  _globals['_RECEIPTSTATUS']._serialized_end=4135
  _globals['_REQUESTCONTEXT']._serialized_start=25
  _globals['_REQUESTCONTEXT']._serialized_end=93
  _globals['_RECEIPT']._serialized_start=95
  _globals['_RECEIPT']._serialized_end=173
  _globals['_EXECUTEATOMICREQUEST']._serialized_start=176
  _globals['_EXECUTEATOMICREQUEST']._serialized_end=382
  _globals['_OPERATION']._serialized_start=385
  _globals['_OPERATION']._serialized_end=637
  _globals['_CREATENODEOP']._serialized_start=639
  _globals['_CREATENODEOP']._serialized_end=750
  _globals['_UPDATENODEOP']._serialized_start=752
  _globals['_UPDATENODEOP']._serialized_end=835
  _globals['_DELETENODEOP']._serialized_start=837
  _globals['_DELETENODEOP']._serialized_end=880
  _globals['_CREATEEDGEOP']._serialized_start=882
  _globals['_CREATEEDGEOP']._serialized_end=997
  _globals['_DELETEEDGEOP']._serialized_start=999
  _globals['_DELETEEDGEOP']._serialized_end=1094
  _globals['_NODEREF']._serialized_start=1096
  _globals['_NODEREF']._serialized_end=1188
  _globals['_TYPEDNODEREF']._serialized_start=1190
  _globals['_TYPEDNODEREF']._serialized_end=1233
  _globals['_EXECUTEATOMICRESPONSE']._serialized_start=1236
  _globals['_EXECUTEATOMICRESPONSE']._serialized_end=1422
  _globals['_GETRECEIPTSTATUSREQUEST']._serialized_start=1424
  _globals['_GETRECEIPTSTATUSREQUEST']._serialized_end=1517
  _globals['_GETRECEIPTSTATUSRESPONSE']._serialized_start=1519
  _globals['_GETRECEIPTSTATUSRESPONSE']._serialized_end=1601
  _globals['_GETNODEREQUEST']._serialized_start=1603
  _globals['_GETNODEREQUEST']._serialized_end=1696
  _globals['_GETNODERESPONSE']._serialized_start=1698
  _globals['_GETNODERESPONSE']._serialized_end=1760
  _globals['_GETNODESREQUEST']._serialized_start=1762
  _globals['_GETNODESREQUEST']._serialized_end=1857
  _globals['_GETNODESRESPONSE']._serialized_start=1859
  _globals['_GETNODESRESPONSE']._serialized_end=1929
  _globals['_QUERYNODESREQUEST']._serialized_start=1932
  _globals['_QUERYNODESREQUEST']._serialized_end=2101
  _globals['_QUERYNODESRESPONSE']._serialized_start=2103
  _globals['_QUERYNODESRESPONSE']._serialized_end=2193
  _globals['_NODE']._serialized_start=2196
  _globals['_NODE']._serialized_end=2356
  _globals['_GETEDGESREQUEST']._serialized_start=2359
  _globals['_GETEDGESREQUEST']._serialized_end=2489
  _globals['_GETEDGESRESPONSE']._serialized_start=2491
  _globals['_GETEDGESRESPONSE']._serialized_end=2558
  _globals['_EDGE']._serialized_start=2561
  _globals['_EDGE']._serialized_end=2690
  _globals['_SEARCHMAILBOXREQUEST']._serialized_start=2693
  _globals['_SEARCHMAILBOXREQUEST']._serialized_end=2846
  _globals['_SEARCHMAILBOXRESPONSE']._serialized_start=2848
  _globals['_SEARCHMAILBOXRESPONSE']._serialized_end=2937
  _globals['_MAILBOXSEARCHRESULT']._serialized_start=2939
  _globals['_MAILBOXSEARCHRESULT']._serialized_end=3031
  _globals['_GETMAILBOXREQUEST']._serialized_start=3034
  _globals['_GETMAILBOXREQUEST']._serialized_end=3208
  _globals['_GETMAILBOXRESPONSE']._serialized_start=3210
  _globals['_GETMAILBOXRESPONSE']._serialized_end=3308
  _globals['_MAILBOXITEM']._serialized_start=3311
  _globals['_MAILBOXITEM']._serialized_end=3496
  _globals['_HEALTHREQUEST']._serialized_start=3498
  _globals['_HEALTHREQUEST']._serialized_end=3513
  _globals['_HEALTHRESPONSE']._serialized_start=3516
  _globals['_HEALTHRESPONSE']._serialized_end=3679
  _globals['_HEALTHRESPONSE_COMPONENTSENTRY']._serialized_start=3630
  _globals['_HEALTHRESPONSE_COMPONENTSENTRY']._serialized_end=3679
  _globals['_GETSCHEMAREQUEST']._serialized_start=3681
  _globals['_GETSCHEMAREQUEST']._serialized_end=3735
  _globals['_GETSCHEMARESPONSE']._serialized_start=3737
  _globals['_GETSCHEMARESPONSE']._serialized_end=3798
  _globals['_LISTTENANTSREQUEST']._serialized_start=3800
  _globals['_LISTTENANTSREQUEST']._serialized_end=3820
  _globals['_LISTTENANTSRESPONSE']._serialized_start=3822
  _globals['_LISTTENANTSRESPONSE']._serialized_end=3882
  _globals['_TENANTINFO']._serialized_start=3884
  _globals['_TENANTINFO']._serialized_end=3915
  _globals['_LISTMAILBOXUSERSREQUEST']._serialized_start=3917
  _globals['_LISTMAILBOXUSERSREQUEST']._serialized_end=3961
  _globals['_LISTMAILBOXUSERSRESPONSE']._serialized_start=3963
  _globals['_LISTMAILBOXUSERSRESPONSE']._serialized_end=4007
  _globals['_ENTDBSERVICE']._serialized_start=4138
  _globals['_ENTDBSERVICE']._serialized_end=5122
# @@protoc_insertion_point(module_scope)
